# Leabharlann ONDER

Π_172_ [![PyPI](https://img.shields.io/pypi/v/pyhelper-tools-jbhm?style=for-the-badge&label=PyPI&color=blue)](https://pypi.org/project/pyhelper-tools-jbhm/)

## 🌍 cànanan ri fhaighinn

Tha Pyhelper a 'tabhann eadar-theangachaidhean togte airson suas ri ** 131 cànan ** * A' gabhail a-steach:

Π_170_ Π_169_ Π_168_ Π_165_ Π_162_ [![sv](https://img.shields.io/badge/lang-sv-blue.svg)](readme/README.sv.md)  
Π_160_ Π_159_158_ Π_157_ Π_153_152_ Π_151_  
Π_150_ Π_149_ Π_1417_ Π_143_ Π_142_ Π_141_  
Π_140_ Π_139_ Π_138_ Π_132_ Π_133_ Π_132_ Π_131_  
Π_130_ Π_129_ [![gl](https://img.shields.io/badge/lang-gl-green.svg)](readme/README.gl.md) Π_124_ Π_122_ Π_122_  
[![iw](https://img.shields.io/badge/lang-iw-purple.svg)](readme/README.iw.md) Π_119_ Π_118_ Π_114_ Π_112_ Π_111_  
Π_110_ Π_109_ Π_108_ Π_106_ Π_103_ Π_102_ Π_101_  
Π_100_ [![la](https://img.shields.io/badge/lang-la-orange.svg)](readme/README.la.md) Π_98_ Π_96_ Π_93_ Π_92_ [![mg](https://img.shields.io/badge/lang-mg-red.svg)](readme/README.mg.md)  
Π_90_ [![ml](https://img.shields.io/badge/lang-ml-orange.svg)](readme/README.ml.md) Π_88_ Π_86_ Π_81_ Π_81_ Π_80_  
Π_79_ Π_78_ Π_77_ Π_75_ Π_70_ Π_79_  
Π_68_ Π_67_ Π_65_ Π_61_ Π_69_ [![te](https://img.shields.io/badge/lang-te-green.svg)](readme/README.te.md)  
Π_57_ [![ti](https://img.shields.io/badge/lang-ti-red.svg)](readme/README.ti.md) Π_55_ Π_51_ Π_49_ Π_48_ Π_47_  
Π_46_ Π_45_ Π_44_ [![zu](https://img.shields.io/badge/lang-zu-green.svg)](readme/README.zu.md)

---


## 🚀 Stàladh

Stàlaich bho PYPI:

Π_42_

---

## 📖 tar-shealladh

** Tha Pyhelper ** na inneal ioma-nota Python air a dhealbhadh gus mion-sgrùdadh, sgrùdadh, sgrùdadh dàta, obair-obrach staitistigeachd **.  
Tha e ag aonachadh gu sàmhail gu bhith acadaimigeach, rannsachadh, agus pròiseactan proifeasanta, a 'toirt cothrom dhut fòcas a chuir air Còd Boilerplaplaid.

Prìomh bhuannachdan:
- 🧮 Staitistig agus goireasan matamataigs a-steach ** ** 
- 📊 Uidheam furasta a chleachdadh ** Mèirle-sgrìobhaidh Dàta ** 
- 🗂 Handy ** làimhseachadh faidhle agus sgrùdadh ** 
- 🔍 ** Dearbhadh co-chòrdail ** airson Python Faidhlichean
- 🌍 * ** Taic ioma-chànan ** le eadar-theangachadh deiseil airson a chleachdadh
- 🚀 Optimized airson ** prototyping luath ** agus ** foghlam ** 

---

## ✨ prìomh fheartan

### 📊 lèirsinn dàta
- Clàran bàr: còmhnard & interical Π_39_  
- Plotaichean cuairteachaidh: Hoksgrams Π_38_,, plotaichean bogsa Π_37_, KDE Plots Π_36_  
- Plots coimeasach: fidheall, swarm, plotaichean stiall  
- Mion-sgrùdadh Correntulation: teas luchd-teas Π_35_, plotaichean sgapte Π_34_  
- LEASACHADH LÀRACH: Palannan plotaichean, co-phlotaichean, plotaichean regression  
- Clàran dàta: taisbeanaidhean bùird cruthaichte Π_33_  

### 📈 Mion-sgrùdadh staitistigeil
- ** CenDend meadhanach ** : a 'ciallachadh (`get_media`), meadhan (`get_median`), modh Π_30_  
- ** sgapte ** : raon (`get_rank`) eadar-dhealachadh (`get_var`), gluasaid àbhaisteach (`get_desv`)  
- ** Mion-sgrùdadh ** A 'GABHAIL A-STEACH IARRTASAN Π_26_, orghan IQR, gnàthachadh, cruth-atharrachaidh cumhachdach  
- ** LOGHALCTION OPERLEND ** : IQR AGUS Z-Dòrn  

### 🗂️ Riaghladh faidhle
- Lorg smart le Π_25_ (auto-detect CSV, JSON, XML, etc.)  
- Taic ioma-chruth Π_23_  
- riaghladh stòr-dàta SQL le clas Π_22_ clas  
- goireasan tionndaidh (`convert_file`)  

### 🛠️ Innealan leasaiche
- Cuir an siostam isean Π_20_  
- co-chòrdadh a 'sgrùdadh (`check_syntax`, `PythonFileChecker`)  
- Mearachd beairteach a 'toirt cunntas air Π_18_  
- Siostam Taic Amalaichte Π_17_  

### 🌍 Inforiament
- Eadar-theangachaidhean a chaidh a thogail 100+  
- Luchdaich eadar-theangachadh àbhaisteach  
- A 'tionndadh cànain Runtime Π_16_ Get_15_ CRO_14_ ``


### staitistig bunaiteach
Π_12_

### sealladh
Π_11_

### A 'làimhseachadh faidhle
Π_10_

### Eadar-theangachadh Custom
Π_9_

### Dearbhadh Syntax
Π_8_

---

## 📂 Structar a 'phròiseict

Π_7_

---

## 📜 License

Tha am pròiseact seo ceadaichte fo na h-** Π_5_ π_4 _ ** .  
Faic am faidhle [LICENSE](LICENSE) Faidhle airson mion-fhiosrachadh.

---

## 🔮 RoadMap

- seòrsaichean lèirsinneach a bharrachd

- Taic stòr-dàta leudaichte (NoSQL, graph databases)

- Iomairt Ionnsachaidh Innealan

- Eadar-aghaidh stèidhichte air an lìon

- Siostam plugan

---

⚡ Deiseil gus supercharge a chuir air leth-obrach air an sruth-obrach agad le ** pyhelper ** ? Tòisich a 'sgrùdadh an-diugh!